==> skill-core-16.0.2-sources.jar: com/ptteng/common/skill/service/StageReplayService.java <==
package com.ptteng.common.skill.service;

import java.util.List;
import java.util.Map;

import org.osoa.sca.annotations.Remotable;

import com.ptteng.common.skill.model.StageReplay;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.dao.BaseDaoService;

@Remotable
public interface StageReplayService extends BaseDaoService {

	



   		   
		
		public Long insert(StageReplay stageReplay)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<StageReplay> insertList(List<StageReplay> stageReplayList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean delete(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean update(StageReplay stageReplay)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean updateList(List<StageReplay> stageReplayList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public StageReplay getObjectById(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<StageReplay> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException;
		  
    	
	


			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer  countStageReplayIdsByStatusOrderBySort(Integer status)throws ServiceException, ServiceDaoException;
					
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long>  getStageReplayIdsByStatusOrderBySort(Integer status, Integer start, Integer limit)throws ServiceException, ServiceDaoException;
		
	
	
	
	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long> getStageReplayIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException;

	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer countStageReplayIds() throws ServiceException, ServiceDaoException;
	

}

==> skill-core-30.0.0-sources.jar: com/ptteng/common/skill/service/StageReplayService.java <==
package com.ptteng.common.skill.service;

import java.util.List;
import java.util.Map;

import org.osoa.sca.annotations.Remotable;

import com.ptteng.common.skill.model.StageReplay;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.dao.BaseDaoService;

@Remotable
public interface StageReplayService extends BaseDaoService {

	



   		   
		
		public Long insert(StageReplay stageReplay)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<StageReplay> insertList(List<StageReplay> stageReplayList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean delete(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean update(StageReplay stageReplay)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean updateList(List<StageReplay> stageReplayList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public StageReplay getObjectById(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<StageReplay> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException;
		  
    	
	


			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer  countStageReplayIdsByNameOrderBySort(String name)throws ServiceException, ServiceDaoException;
			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer  countStageReplayIdsByStatusOrderBySort(Integer status)throws ServiceException, ServiceDaoException;
					
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long>  getStageReplayIdsByNameOrderBySort(String name, Integer start, Integer limit)throws ServiceException, ServiceDaoException;
			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long>  getStageReplayIdsByStatusOrderBySort(Integer status, Integer start, Integer limit)throws ServiceException, ServiceDaoException;
		
	
	
	
	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long> getStageReplayIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException;

	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer countStageReplayIds() throws ServiceException, ServiceDaoException;
	

}
